@@ -10,29 +10,30 @@ nonetheless be modified in memory.
 
 The `cf` package can:
 
-* read field constructs from netCDF, CDL, PP and UM datasets,
+* read field constructs and domain constructs from netCDF, CDL, PP and
+  UM datasets,
 
-* create new field constructs in memory,
+* create new field and domain constructs in memory,
 
-* inspect field constructs,
+* inspect field and domain constructs,
 
-* test whether two field constructs are the same,
+* test whether two constructs are the same,
 
-* modify field construct metadata and data,
+* modify field and domain construct metadata and data,
 
-* create subspaces of field constructs,
+* create subspaces of field and domain constructs,
 
 * write and append field constructs to netCDF datasets on disk,
 
-* incorporate, and create, metadata stored in external files (*new in
-  version 3.0.0*),
+* incorporate, and create, metadata stored in external files,
 
 * read, write, and create data that have been compressed by convention
   (i.e. ragged or gathered arrays), whilst presenting a view of the
   data in its uncompressed form,
 
-* read, write, and create coordinates defined by geometry cells (*new
-  in version 3.2.0*),
+* read, write, and create coordinates defined by geometry cells,
+
+* read netCDF and CDL datasets containing hierarchical groups,
 
 * combine field constructs arithmetically,
 
@@ -42,7 +43,7 @@ The `cf` package can:
 * perform statistical collapses on field constructs,
 
 * perform histogram, percentile and binning operations on field
-  constructs (*new in version 3.0.3*),
+  constructs,
 
 * regrid field constructs with (multi-)linear, nearest neighbour,
   first- and second-order conservative and higher order patch recovery
@@ -56,16 +57,9 @@ The `cf` package can:
   vorticity).
 
 All of the above use LAMA functionality, which allows multiple fields
-larger than the available memory to exist and be manipulated.
-
-
-**Hierarchical groups**
-
-Hierarchical groups provide a powerful mechanism to structure
-variables within datasets. A future release of `cf` will include
-support for netCDF4 files containing data organised in hierarchical
-groups, but this is not available in version 3.2.0 (even though it is
-allowed in CF-1.8).
+larger than the available memory to exist and be manipulated. (Note:
+work is underway to replace this functionality with a dask
+implementation.)
 
 
 **Visualization**
@@ -79,10 +73,9 @@ See the :ref:`cf-python home page <cf-python-home>` for documentation,
 installation and source code.
 
 """
-
-__Conventions__ = "CF-1.8"
-__date__ = "2021-06-10"
-__version__ = "3.10.0"
+__Conventions__ = "CF-1.9"
+__date__ = "2021-10-08"
+__version__ = "3.11.0"
 
 _requires = (
     "numpy",
@@ -108,19 +101,13 @@ import importlib.util
 import platform
 
 # Check the version of Python
-_minimum_vn = "3.6.0"
+_minimum_vn = "3.7.0"
 if LooseVersion(platform.python_version()) < LooseVersion(_minimum_vn):
     raise ValueError(
         f"Bad python version: cf requires python version {_minimum_vn} "
         f"or later. Got {platform.python_version()}"
     )
 
-if LooseVersion(platform.python_version()) < LooseVersion("3.7.0"):
-    print(
-        "\nDeprecation Warning: Python 3.6 support will be removed at "
-        "the next version of cf\n"
-    )
-
 _found_ESMF = bool(importlib.util.find_spec("ESMF"))
 
 # TODODASK - Remove the next 2 lines when the move to dask is complete
@@ -193,8 +180,8 @@ if LooseVersion(cfunits.__version__) < LooseVersion(_minimum_vn):
     )
 
 # Check the version of cfdm
-_minimum_vn = "1.8.9.0"
-_maximum_vn = "1.8.10.0"
+_minimum_vn = "1.9.0.0"
+_maximum_vn = "1.9.1.0"
 _cfdm_version = LooseVersion(cfdm.__version__)
 if not LooseVersion(_minimum_vn) <= _cfdm_version < LooseVersion(_maximum_vn):
     raise RuntimeError(
@@ -225,6 +212,7 @@ from .units import Units
 
 from .constructlist import ConstructList
 from .fieldlist import FieldList
+from .domainlist import DomainList
 
 from .dimensioncoordinate import DimensionCoordinate
 from .auxiliarycoordinate import AuxiliaryCoordinate
@@ -284,6 +272,7 @@ from .query import (
     son,
     seasons,
 )
+
 from .constants import *  # noqa: F403
 from .functions import *  # noqa: F403
 from .maths import relative_vorticity, histogram
