@@ -2,11 +2,9 @@ import logging
 
 import numpy
 
-from ..functions import parse_indices, get_subspace
-
+from ..functions import get_subspace, parse_indices
 from . import abstract
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -59,13 +57,3 @@ class RaggedIndexedSubarray(abstract.CompressedSubarray):
             )
 
             return get_subspace(uarray, indices)
-
-
-#    def __repr__(self):
-#        '''x.__repr__() <==> repr(x)
-#
-#        '''
-#        return "<CF %s: %s>" % (self.__class__.__name__, str(self.array))
-
-
-# --- End: class
