@@ -1,24 +1,17 @@
+import cfdm
 from numpy import empty as numpy_empty
 from numpy import result_type as numpy_result_type
 
-import cfdm
-
-from . import Bounds
-
-from .timeduration import TimeDuration
-from .units import Units
-
+from . import Bounds, mixin
 from .data.data import Data
-
-from . import mixin
-
-from .functions import _DEPRECATION_ERROR_KWARGS, _DEPRECATION_ERROR_ATTRIBUTE
-
 from .decorators import (
+    _deprecated_kwarg_check,
     _inplace_enabled,
     _inplace_enabled_define_and_cleanup,
-    _deprecated_kwarg_check,
 )
+from .functions import _DEPRECATION_ERROR_ATTRIBUTE, _DEPRECATION_ERROR_KWARGS
+from .timeduration import TimeDuration
+from .units import Units
 
 
 class DimensionCoordinate(
@@ -569,9 +562,7 @@ class DimensionCoordinate(
                 if not self.Units.isreftime:
                     raise ValueError(
                         "Can't create reference time bounds for "
-                        "non-reference time coordinates: {0!r}".format(
-                            self.Units
-                        )
+                        f"non-reference time coordinates: {self.Units!r}"
                     )
 
                 bounds = numpy_empty((size, 2), dtype=object)
@@ -809,40 +800,35 @@ class DimensionCoordinate(
     @_inplace_enabled(default=False)
     def roll(self, axis, shift, inplace=False, i=False):
         """Rolls the dimension coordinate along a cyclic axis."""
-        if self.size <= 1:
-            if inplace:
-                return
-            else:
-                return self.copy()
+        c = _inplace_enabled_define_and_cleanup(self)
 
-        shift %= self.size
-
-        #        period = self._custom.get('period')
-        period = self.period()
+        size = c.size
+        if size <= 1:
+            return c
 
+        shift %= size
         if not shift:
             # Null roll
-            if inplace:
-                return
-            else:
-                return self.copy()
-        elif period is None:
+            return c
+
+        #        period = self._custom.get('period')
+        period = c.period()
+
+        if period is None:
             raise ValueError(
-                "Can't roll {} when no period has been set".format(
-                    self.__class__.__name__
-                )
+                f"Can't roll {self.__class__.__name__} when no period has "
+                "been set"
             )
 
-        direction = self.direction()
+        direction = c.direction()
 
-        centre = self._centre(period)
+        centre = c._centre(period)
 
         if axis not in [0, -1]:
             raise ValueError(
-                "Can't roll axis {} when there is only one axis".format(axis)
+                f"Can't roll axis {axis} when there is only one axis"
             )
 
-        c = _inplace_enabled_define_and_cleanup(self)
         super(DimensionCoordinate, c).roll(axis, shift, inplace=True)
 
         c.dtype = numpy_result_type(c.dtype, period.dtype)
