@@ -1,21 +1,16 @@
-from . import mixin
-from . import ConstructList
-
+from . import ConstructList, mixin
 from .functions import _DEPRECATION_ERROR_METHOD
 
 
 class FieldList(mixin.FieldDomainList, ConstructList):
-    """An ordered sequence of fields.
-
-    Each element of a field list is a field construct.
+    """An ordered sequence of field constructs.
 
     A field list supports the python list-like operations (such as
     indexing and methods like `!append`). These methods provide
-    functionality similar to that of a :ref:`built-in list
-    <python:tut-morelists>`. The main difference is that when a field
-    construct element needs to be assessed for equality its
-    `~cf.Field.equals` method is used, rather than the ``==``
-    operator.
+    functionality similar to that of a built-in list. The main
+    difference is that when a field construct element needs to be
+    assessed for equality its `~cf.Field.equals` method is used,
+    rather than the ``==`` operator.
 
     """
 
@@ -30,9 +25,6 @@ class FieldList(mixin.FieldDomainList, ConstructList):
         """
         super().__init__(constructs=fields)
 
-    # ----------------------------------------------------------------
-    # Methods
-    # ----------------------------------------------------------------
     def concatenate(self, axis=0, _preserve=True):
         """Join the sequence of fields together.
 
@@ -220,7 +212,7 @@ class FieldList(mixin.FieldDomainList, ConstructList):
                 return
 
             return self._default(
-                default, "select_field() can't return {n} fields"
+                default, f"select_field() can't return {n} fields"
             )
 
         return out[0]
