@@ -1,9 +1,6 @@
 from ...constants import _file_to_fh
-from ...functions import (
-    open_files_threshold_exceeded,  # abspath
-    close_one_file,
-)
-
+from ...functions import open_files_threshold_exceeded  # abspath
+from ...functions import close_one_file
 from ...umread_lib.umfile import File
 
 _file_to_UM = _file_to_fh.setdefault("UM", {})
