@@ -3,16 +3,16 @@ from operator import itemgetter
 
 import numpy as np
 
-from ..functions import regrid_logging
-from ..dimensioncoordinate import DimensionCoordinate
-from ..data import Data
 from .. import _found_ESMF
+from ..data import Data
+from ..dimensioncoordinate import DimensionCoordinate
+from ..functions import regrid_logging
 
 if _found_ESMF:
     try:
         import ESMF
-    except Exception as error:
-        print(f"WARNING: Can not import ESMF for regridding: {error}")
+    except Exception:
+        _found_ESMF = False
 
 from .regridoperator import (
     RegridOperator,
@@ -71,21 +71,27 @@ def regrid_compute_mass_grid(
     return mass
 
 
-def regrid_get_latlon(f, name, axes=None):
-    """Retrieve the latitude and longitude coordinates of this field and
-    associated information. If 1-d lat/long coordinates are found then
-    these are returned. Otherwise, 2-d lat/long coordinates are searched
-    for and if found returned.
+def regrid_get_latlon(f, name, method, axes=None):
+    """Get latitude and longitude coordinate information.
+
+    Retrieve the latitude and longitude coordinates of a field, as
+    well as some associated information. If 1-d lat/lon coordinates
+    are found then these are returned. Otherwise if 2-d lat/lon
+    coordinates found then these are returned.
 
     :Parameters:
 
         f: `Field`
-            The source or destination field.
+            The source or destination field from which to get the
+            information.
 
         name: `str`
             A name to identify the field in error messages. Either
             ``'source'`` or ``'destination'``.
 
+        method: `str`
+            The regridding method.
+
         axes: `dict`, optional
             A dictionary specifying the X and Y axes, with keys
             ``'X'`` and ``'Y'``.
@@ -99,14 +105,14 @@ def regrid_get_latlon(f, name, axes=None):
     :Returns:
 
         `list`, `list`, `list`, `list`, `bool`
-            * The keys of the x and y dimension coordinates.
+            * The keys of the X and Y dimension coordinates.
 
-            * The sizes of the x and y dimension coordinates.
+            * The sizes of the X and Y dimension coordinates.
 
-            * The keys of the x and y coordinate (1-d dimension
+            * The keys of the X and Y coordinate (1-d dimension
               coordinate, or 2-d auxilliary coordinates).
 
-            * The x and y coordinates (1-d dimension coordinates or
+            * The X and Y coordinates (1-d dimension coordinates or
               2-d auxilliary coordinates).
 
             * True if 2-d auxiliary coordinates are returned or if 1-d
@@ -124,7 +130,7 @@ def regrid_get_latlon(f, name, axes=None):
             item=True,
             default=ValueError(
                 f"No unique X dimension coordinate found for the {name} "
-                "field. If none is present you "
+                f"field {f!r}. If none is present you "
                 "may need to specify the axes keyword."
             ),
         )
@@ -133,7 +139,7 @@ def regrid_get_latlon(f, name, axes=None):
             item=True,
             default=ValueError(
                 f"No unique Y dimension coordinate found for the {name} "
-                "field. If none is present you "
+                f"field {f!r}. If none is present you "
                 "may need to specify the axes keyword."
             ),
         )
@@ -151,7 +157,7 @@ def regrid_get_latlon(f, name, axes=None):
             if key not in axes:
                 raise ValueError(
                     f"Key {key!r} must be specified for axes of {name} "
-                    "field."
+                    f"field {f!r}."
                 )
 
         if axes["X"] in (1, 0) and axes["Y"] in (0, 1):
@@ -186,7 +192,7 @@ def regrid_get_latlon(f, name, axes=None):
                 axes["X"],
                 key=True,
                 default=ValueError(
-                    f"'X' axis specified for {name} field not found."
+                    f"'X' axis specified for {name} {f!r} field not found."
                 ),
             )
 
@@ -194,7 +200,7 @@ def regrid_get_latlon(f, name, axes=None):
                 axes["Y"],
                 key=True,
                 default=ValueError(
-                    f"'Y' axis specified for {name} field not found."
+                    f"'Y' axis specified for {name} field {f!r} not found."
                 ),
             )
 
@@ -218,7 +224,7 @@ def regrid_get_latlon(f, name, axes=None):
                 if lon_found:
                     raise ValueError(
                         "The 2-d auxiliary longitude coordinate "
-                        f"of the {name} field is not unique."
+                        f"of the {name} field {f!r} is not unique."
                     )
                 else:
                     lon_found = True
@@ -229,7 +235,7 @@ def regrid_get_latlon(f, name, axes=None):
                 if lat_found:
                     raise ValueError(
                         "The 2-d auxiliary latitude coordinate "
-                        f"of the {name} field is not unique."
+                        f"of the {name} field {f!r} is not unique."
                     )
                 else:
                     lat_found = True
@@ -239,31 +245,37 @@ def regrid_get_latlon(f, name, axes=None):
         if not lon_found or not lat_found:
             raise ValueError(
                 "Both longitude and latitude coordinates "
-                f"were not found for the {name} field."
+                f"were not found for the {name} field {f!r}."
             )
 
         if axes is not None:
             if set(axis_keys) != set(data_axes[x_key]):
                 raise ValueError(
                     "Axes of longitude do not match "
-                    f"those specified for {name} field."
+                    f"those specified for {name} field {f!r}."
                 )
 
             if set(axis_keys) != set(data_axes[y_key]):
                 raise ValueError(
                     "Axes of latitude do not match "
-                    f"those specified for {name} field."
+                    f"those specified for {name} field {f!r}."
                 )
 
         coords_2D = True
     else:
         coords_2D = False
-        # Check for size 1 latitude or longitude dimensions
-        if x_size == 1 or y_size == 1:
-            raise ValueError(
-                "Neither the longitude nor latitude dimension coordinates "
-                f"of the {name} field can be of size 1."
-            )
+
+    # Check for size 1 latitude or longitude dimensions if source grid
+    # (a size 1 dimension is only problematic for the source grid in ESMF)
+    if (
+        name == "source"
+        and method in ("linear", "bilinear", "patch")
+        and (x_size == 1 or y_size == 1)
+    ):
+        raise ValueError(
+            f"Neither the longitude nor latitude dimensions of the {name}"
+            f"field {f!r} can be of size 1 for {method!r} regridding."
+        )
 
     coord_keys = [x_key, y_key]
     coords = [x, y]
@@ -323,13 +335,17 @@ def regrid_get_axis_indices(f, axis_keys):
             size-1 dimensions inserted into its data in-place.
 
         axis_keys: sequence
-            A sequence of axis specifiers.
+            A sequence of domain axis identifiers for the axes being
+            regridded.
 
     :Returns:
 
-        `list`, `numpy.ndarray`
-            A list of the indices of the specified axes; and the rank
-            order of the axes.
+        `list`, `list`, `numpy.ndarray`
+            * The indices of the specified axes.
+
+            * The indices of the non-specified field data axes .
+
+            * The rank order of the axes.
 
     """
     data_axes = f.get_data_axes()
@@ -341,7 +357,7 @@ def regrid_get_axis_indices(f, axis_keys):
             axis_index = data_axes.index(axis_key)
         except ValueError:
             f.insert_dimension(axis_key, position=0, inplace=True)
-            axis_index = data_axes.index(axis_key)
+            axis_index = 0
 
         axis_indices.append(axis_index)
 
@@ -352,7 +368,11 @@ def regrid_get_axis_indices(f, axis_keys):
     order = np.empty((n,), dtype=int)
     order[tmp] = np.arange(n)
 
-    return axis_indices, order
+    non_regridding_axis_indices = [
+        i for i in range(f.ndim) if i not in axis_indices
+    ]
+
+    return axis_indices, non_regridding_axis_indices, order
 
 
 def regrid_get_coord_order(f, axis_keys, coord_keys):
@@ -565,9 +585,9 @@ def regrid_get_reordered_sections(
 
     """
     # If we had dynamic masking, we wouldn't need this method, we
-    # could sdimply replace it in the clling function with a call to
+    # could simply replace it in the calling function with a call to
     # Data.section. However, we don't have it, so this allows us to
-    # possibibly reduce the number of trasnistions between different
+    # possibly reduce the number of transitions between different
     # masks - each change is slow.
     data_axes = src.get_data_axes()
 
@@ -753,6 +773,10 @@ def regrid_compute_field_mass(
     # Insert the two masses into the dictionary for comparison
     _compute_field_mass[k] = (srcmass, dstmass)
 
+    # Release memory
+    srcareafield.destroy()
+    dstareafield.destroy()
+
 
 def regrid_get_regridded_data(f, method, fracfield, dstfield, dstfracfield):
     """Get the regridded data.
@@ -1210,6 +1234,12 @@ def regrid_initialize():
             A singleton instance of the `ESMF` manager.
 
     """
+    if not _found_ESMF:
+        raise RuntimeError(
+            "Regridding methods will not work unless "
+            "the ESMF library is installed"
+        )
+
     return ESMF.Manager(debug=bool(regrid_logging()))
 
 
