@@ -83,8 +83,7 @@ class FieldTest(unittest.TestCase):
     f1 = cf.example_field(1)
 
     def test_Field_creation_commands(self):
-        for i in range(7):
-            f = cf.example_field(i)
+        for f in cf.example_fields():
             f.creation_commands()
 
         f = self.f1
@@ -489,9 +488,8 @@ class FieldTest(unittest.TestCase):
                     b = getattr(f.data, method)(axes=axes)
                     self.assertTrue(
                         a.equals(b, rtol=1e-05, atol=1e-08, verbose=2),
-                        "{} weights={}, axes={}, {!r}, {!r}".format(
-                            method, weights, axes, a, b
-                        ),
+                        f"{method} weights={weights}, axes={axes}, {a!r}, "
+                        f"{b!r}",
                     )
 
             for method in (
@@ -510,9 +508,8 @@ class FieldTest(unittest.TestCase):
                     b = getattr(f.data, method)(axes=axes, weights=d_weights)
                     self.assertTrue(
                         a.equals(b, rtol=1e-05, atol=1e-08, verbose=2),
-                        "{} weights={}, axes={}, {!r}, {!r}".format(
-                            method, weights, axes, a, b
-                        ),
+                        f"{method} weights={weights}, axes={axes}, {a!r}, "
+                        f"{b!r}",
                     )
 
             for method in ("integral",):
@@ -524,9 +521,7 @@ class FieldTest(unittest.TestCase):
                 b = getattr(f.data, method)(axes=axes, weights=d_weights)
                 self.assertTrue(
                     a.equals(b, rtol=1e-05, atol=1e-08, verbose=2),
-                    "{} weighted axes={}, {!r}, {!r}".format(
-                        method, axes, a, b
-                    ),
+                    f"{method} weighted axes={axes}, {a!r}, {b!r}",
                 )
 
         for axes in axes_combinations(f):
@@ -546,9 +541,8 @@ class FieldTest(unittest.TestCase):
                     )
                     self.assertTrue(
                         a.equals(b, rtol=1e-05, atol=1e-08, verbose=2),
-                        "{} weights={}, axes={}, {!r}, {!r}".format(
-                            method, weights, axes, a, b
-                        ),
+                        f"{method} weights={weights}, axes={axes}, {a!r}, "
+                        f"{b!r}",
                     )
 
             for method in ("mean_of_upper_decile",):
@@ -562,9 +556,8 @@ class FieldTest(unittest.TestCase):
                     b = getattr(f.data, method)(axes=axes, weights=d_weights)
                     self.assertTrue(
                         a.equals(b, rtol=1e-05, atol=1e-08, verbose=2),
-                        "{} weights={}, axes={}, {!r}, {!r}".format(
-                            method, weights, axes, a, b
-                        ),
+                        f"{method} weights={weights}, axes={axes}, {a!r}, "
+                        f"{b!r}",
                     )
 
     def test_Field_all(self):
@@ -665,7 +658,7 @@ class FieldTest(unittest.TestCase):
                 [ac.shape, ae.shape, af.shape],
                 [ac, ae, af],
             ):
-                message = "method={!r}".format(method)
+                message = f"method={method!r}"
 
                 f.indices(method, time=query1)
 
@@ -717,7 +710,7 @@ class FieldTest(unittest.TestCase):
                 [ac2, ae2, af2],
             ):
 
-                message = "method={!r}".format(method)
+                message = f"method={method!r}"
 
                 h = f.subspace("full", time=query1)
                 g = h.subspace(method, time=query2)
@@ -768,7 +761,7 @@ class FieldTest(unittest.TestCase):
                 [ac3, ae3, af3],
             ):
 
-                message = "method={!r}".format(method)
+                message = f"method={method!r}"
 
                 g = f.subspace(method, time=query3)
                 t = g.coordinate("time")
@@ -967,7 +960,10 @@ class FieldTest(unittest.TestCase):
     def test_Field_flip(self):
         f = self.f.copy()
 
-        g = f[(slice(None, None, -1),) * f.ndim]
+        kwargs = {
+            axis: slice(None, None, -1) for axis in f.domain_axes(todict=True)
+        }
+        g = f.subspace(**kwargs)
 
         h = f.flip()
         self.assertTrue(h.equals(g, verbose=1))
@@ -1031,9 +1027,8 @@ class FieldTest(unittest.TestCase):
                 x0 = g.coordinate("grid_longitude").datum(0)
                 self.assertTrue(
                     x1 > anchor >= x0,
-                    "DECREASING period={}, x0={}, anchor={}, x1={}".format(
-                        period, x1, anchor, x0
-                    ),
+                    f"DECREASING period={period}, x0={x0}, anchor={anchor}, "
+                    f"x1={x1}",
                 )
 
     def test_Field_cell_area(self):
@@ -2246,7 +2241,7 @@ class FieldTest(unittest.TestCase):
     def test_Field_section(self):
         f = cf.read(self.filename2)[0][0:10]
         g = f.section(("X", "Y"))
-        self.assertEqual(len(g), 10, "len(g)={}".format(len(g)))
+        self.assertEqual(len(g), 10, f"len(g)={len(g)}")
 
     def test_Field_squeeze(self):
         f = self.f.copy()
@@ -2337,6 +2332,29 @@ class FieldTest(unittest.TestCase):
             key,
         )
 
+        # Get
+        for identity in (
+            "coordinatereference1",
+            "key%coordinatereference0",
+            "standard_name:atmosphere_hybrid_height_coordinate",
+            "grid_mapping_name:rotated_latitude_longitude",
+        ):
+            key = f.construct_key(identity)
+            c = f.construct(identity)
+
+            self.assertTrue(
+                f.get_coordinate_reference(identity).equals(c, verbose=2)
+            )
+            self.assertEqual(
+                f.get_coordinate_reference(identity, key=True), key
+            )
+
+        with self.assertRaises(ValueError):
+            f.get_coordinate_reference()  # since has two CR constructs
+        g = f.copy()
+        g.del_coordinate_reference("coordinatereference1")
+        g.get_coordinate_reference()  # should work here as has only one CR
+
         # Delete
         self.assertIsNone(f.del_coordinate_reference("qwerty", default=None))
 
