@@ -1,23 +1,18 @@
 import logging
-
-from operator import __add__, __sub__
-
 from collections import namedtuple
+from operator import __add__, __sub__
 
 import numpy
 
-from .cfdatetime import elements
 from .cfdatetime import dt as cf_dt
-from .functions import inspect as cf_inspect
-from .units import Units
-
+from .cfdatetime import elements
 from .data.data import Data
-
 from .decorators import (
     _deprecated_kwarg_check,
     _manage_log_level_via_verbosity,
 )
-
+from .functions import inspect as cf_inspect
+from .units import Units
 
 logger = logging.getLogger(__name__)
 
@@ -337,13 +332,11 @@ class TimeDuration:
             self.duration = abs(Data.asdata(duration))
             units = self.duration.Units
             if not units.istime:
-                raise ValueError("Bad units: {!r}".format(units))
+                raise ValueError(f"Bad units: {units!r}")
 
         if not (units.iscalendartime or units.istime):
             raise ValueError(
-                "Can't create {0} of {1}".format(
-                    self.__class__.__name__, self.duration
-                )
+                f"Can't create {self.__class__.__name__} of {self.duration}"
             )
 
         duration = self.duration
@@ -422,12 +415,12 @@ class TimeDuration:
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "<CF {0}: {1}>".format(self.__class__.__name__, str(self))
+        return f"<CF {self.__class__.__name__}: {str(self)}>"
 
     def __str__(self):
         """x.__str__() <==> str(x)"""
         yyy = [
-            x if y is None else "{0:0>2}".format(y)
+            x if y is None else f"{y:0>2}"
             for x, y in zip(("Y", "M", "D", "h", "m", "s"), self.offset)
         ]
 
@@ -782,16 +775,14 @@ class TimeDuration:
 
         if duration.size != 1:
             raise ValueError(
-                "Can't create {} with more than one value: {!r}".format(
-                    self.__class__.__name__, duration
-                )
+                f"Can't create {self.__class__.__name__} with more than one "
+                f"value: {duration!r}"
             )
 
         if duration < 0:
             raise ValueError(
-                "Can't create {} with with negative duration {!r}".format(
-                    self.__class__.__name__, duration
-                )
+                f"Can't create {self.__class__.__name__} with with negative "
+                f"duration {duration!r}"
             )
 
         if (
@@ -800,9 +791,7 @@ class TimeDuration:
         ):
             # Operator is not one of ==, !=, >=, >, <=, <
             raise ValueError(
-                "Can't create {} of {!r}".format(
-                    self.__class__.__name__, duration.Units
-                )
+                f"Can't create {self.__class__.__name__} of {duration.Units!r}"
             )
 
         if method not in _relational_methods:
@@ -838,9 +827,7 @@ class TimeDuration:
         """
 
         def _dHMS(duration, other, calendar, op):
-            units = Units(
-                "{0} since {1}".format(duration.Units.units, other), calendar
-            )
+            units = Units(f"{duration.Units.units} since {other}", calendar)
             d = op(Data(0.0, units), duration)
             return d.datetime_array.item(())
 
@@ -853,7 +840,7 @@ class TimeDuration:
             if months != months0:
                 raise ValueError(
                     "Fractional months are not supported for  "
-                    "date calculations: {}".format(months0)
+                    f"date calculations: {months0}"
                 )
         elif units == _calendar_months:
             months0 = duration.datum()
@@ -861,7 +848,7 @@ class TimeDuration:
             if months != months0:
                 raise ValueError(
                     "Fractional months are not supported for "
-                    "date calculations: {}".format(months0)
+                    f"date calculations: {months0}"
                 )
         else:
             months = None
@@ -934,7 +921,7 @@ class TimeDuration:
                 (i if j is None else j)
                 for i, j in zip(elements(dt), self.offset)
             ],
-            calendar=getattr(dt, "calendar", None)
+            calendar=getattr(dt, "calendar", None),
         )
 
     # ----------------------------------------------------------------
@@ -962,22 +949,23 @@ class TimeDuration:
         duration = self.duration
         units = duration.Units
 
+        date_prefix = f"P{duration.datum()}"
         if units.equals(_calendar_months):
-            return "P{0}M".format(duration.datum())
+            return f"{date_prefix}M"
         if units.equals(_calendar_years):
-            return "P{0}Y".format(duration.datum())
+            return f"{date_prefix}Y"
         if units.equals(_days):
-            return "P{0}D".format(duration.datum())
-        if units.equals(_hours):
-            return "PT{0}H".format(duration.datum())
-        if units.equals(_minutes):
-            return "PT{0}M".format(duration.datum())
-        if units.equals(_seconds):
-            return "PT{0}S".format(duration.datum())
+            return f"{date_prefix}D"
 
-        raise ValueError(
-            "Bad {0} units: {1!r}".format(self.__class__.__name__, units)
-        )
+        time_prefix = f"PT{duration.datum()}"
+        if units.equals(_hours):
+            return f"{time_prefix}H"
+        if units.equals(_minutes):
+            return f"{time_prefix}M"
+        if units.equals(_seconds):
+            return f"{time_prefix}S"
+
+        raise ValueError(f"Bad {self.__class__.__name__} units: {units!r}")
 
     @property
     def isint(self):
@@ -1465,9 +1453,7 @@ class TimeDuration:
             if not calendar:
                 calendar = None
 
-            units = Units(
-                "{0} since {1}".format(duration.Units.units, dt), calendar
-            )
+            units = Units(f"{duration.Units.units} since {dt}", calendar)
             dt1 = Data(0.0, units)
 
             if not end:
@@ -1497,7 +1483,7 @@ class TimeDuration:
             if int_months != months:
                 raise ValueError(
                     "Can't create a time interval of a non-integer number "
-                    "of calendar months: {0}".format(months)
+                    f"of calendar months: {months}"
                 )
         elif units == _calendar_months:
             months = duration.datum()
@@ -1505,7 +1491,7 @@ class TimeDuration:
             if int_months != months:
                 raise ValueError(
                     "Can't create a time interval of a non-integer number "
-                    "of calendar months: {0}".format(months)
+                    f"of calendar months: {months}"
                 )
         else:
             int_months = None
@@ -1551,11 +1537,11 @@ class TimeDuration:
             return dt0, dt1
 
         if iso == "start and end":
-            return "{0}/{1}".format(dt0, dt1)
+            return f"{dt0}/{dt1}"
         if iso == "start and duration":
-            return "{0}/{1}".format(dt0, self.iso)
+            return f"{dt0}/{self.iso}"
         if iso == "duration and end":
-            return "{0}/{1}".format(self.iso, dt1)
+            return f"{self.iso}/{dt1}"
 
     def bounds(self, dt, direction=True):
         """Return a time interval containing a date-time.
